
package com.tmerclub.cloud.supplier.dto;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;

/**
 * 工商信息审核记录
 *
 * @author chiley
 * @date 2022/9/1 16:16
 */
@Data
public class SupplierCompanyAuditingDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = 1L;
    /**
     * 工商信息审核id
     */
    private Long companyAuditingId;
    /**
     * 申请人id
     */
    @Schema(description = "申请人id")
    private String userId;

    /**
     * 供应商id
     */
    @Schema(description = "供应商id")
    private Long supplierId;

    /**
     * 工商信息id
     */
    @Schema(description = "工商信息id")
    private Long supplierCompanyId;

    /**
     * 供应商名称
     */
    @Schema(description = "供应商名称")
    private String supplierName;

    /**
     * 审核人id
     */
    @Schema(description = "审核人id")
    private Long auditorId;

    /**
     * 0 未审核 1已通过 -1未通过
     */
    @Schema(description = "0 未审核 1已通过 -1未通过")
    private Integer status;

    @Schema(description = "申请起始时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date beginTime;

    @Schema(description = "申请结束时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date endTime;

    @Schema(description = "备注")
    private String remarks;

    public SupplierCompanyAuditingDTO() {

    }

    public SupplierCompanyAuditingDTO(Long companyAuditingId, Integer status, String remarks) {
        this.companyAuditingId = companyAuditingId;
        this.status = status;
        this.remarks = remarks;
    }

}
