
package com.tmerclub.cloud.product.mapper;

import com.tmerclub.cloud.api.product.dto.CategoryShopDTO;
import com.tmerclub.cloud.product.bo.CategoryRateBO;
import com.tmerclub.cloud.product.model.CategoryShop;
import com.tmerclub.cloud.product.vo.CategoryShopVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 店铺签约分类关联信息
 *
 * @Author lth
 * @Date 2021/4/25 14:37
 */
public interface CategoryShopMapper {
    /**
     * 根据店铺id删除所有以签约的信息
     *
     * @param shopId
     * @param sysType
     */
    void deleteByShopId(@Param("shopId") Long shopId, @Param("sysType") Integer sysType);

    /**
     * 批量保存分类签约信息
     *
     * @param categoryShopDTOList
     * @param shopId
     * @param sysType
     */
    void saveBatch(@Param("categoryShopList") List<CategoryShopDTO> categoryShopDTOList, @Param("shopId") Long shopId, @Param("sysType") Integer sysType);

    /**
     * 根据店铺id获取签约分类信息列表
     *
     * @param shopId
     * @param lang
     * @param sysType
     * @return
     */
    List<CategoryShopVO> listByShopId(@Param("shopId") Long shopId, @Param("lang") Integer lang, @Param("sysType") Integer sysType);

    /**
     * 根据店铺分类关联信息id获取店铺分类关联信息
     *
     * @param categoryShopId 店铺分类关联信息id
     * @return 店铺分类关联信息
     */
    CategoryShop getByCategoryShopId(@Param("categoryShopId") Long categoryShopId);

    /**
     * 根据店铺分类关联信息id删除店铺分类关联信息
     *
     * @param categoryShopId
     */
    void deleteById(@Param("categoryShopId") Long categoryShopId);

    /**
     * 获取店铺签约的平台三级分类佣金
     *
     * @param shopId  店铺id
     * @param sysType
     * @return 平台佣金
     */
    List<CategoryRateBO> listRateByShopId(@Param("shopId") Long shopId, @Param("sysType") Integer sysType);

    /**
     * 根据分类id删除店铺分类关联关系
     *
     * @param categoryId
     */
    void deleteByCategoryId(@Param("categoryId") Long categoryId);

    /**
     * 根据分类id获取签约了该分类的店铺id列表
     *
     * @param categoryId
     * @return
     */
    List<Long> listShopIdByCategoryId(@Param("categoryId") Long categoryId);

    /**
     * 根据分类id列表获取店铺id列表
     *
     * @param categoryIds
     * @return
     */
    List<Long> listShopIdByCategoryIds(@Param("categoryIds") List<Long> categoryIds);

    /**
     * 根据店铺id与分类id查询签约关系
     *
     * @param shopId
     * @param categoryId
     * @param sysType
     * @return
     */
    CategoryShopVO getByShopIdAndCategoryId(@Param("shopId") Long shopId, @Param("categoryId") Long categoryId, @Param("sysType") Integer sysType);

    /**
     * 根据店铺id与分类id统计签约数量
     *
     * @param shopId
     * @param categoryId
     * @param sysType
     * @return
     */
    int countByShopIdAndCategoryId(@Param("shopId") Long shopId, @Param("categoryId") Long categoryId, @Param("sysType") Integer sysType);

    /**
     * 根据店铺id获取有相同分类的供应商
     *
     * @param shopId 店铺id
     * @return 供应商ids
     */
    List<Long> getSupplierIdsByShopId(@Param("shopId") Long shopId);


    /**
     * 根据店铺id获取所有分类ids
     *
     * @param shopId  店铺id
     * @param sysType
     * @return 所有分类ids
     */
    List<Long> getCategoryIdsByShopId(@Param("shopId") Long shopId, @Param("sysType") Integer sysType);

    /**
     * 根据分类id获取绑定的供应商id
     *
     * @param categoryIds
     * @return
     */
    List<Long> getSupplyIdByCategoryIds(@Param("categoryIds") List<Long> categoryIds);
}
